@@ -13,8 +13,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from __future__ import print_function
-
 import argparse
 import inspect
 import json
@@ -25,7 +23,6 @@ import warnings
 
 import jsonschema
 import prettytable
-import six
 import sqlalchemy.exc
 
 from rally import api
@@ -68,15 +65,12 @@ def validate_args(fn, *args, **kwargs):
     :param args: the positional arguments supplied
     :param kwargs: the keyword arguments supplied
     """
-    argspec = inspect.getargspec(fn)
-
-    num_defaults = len(argspec.defaults or [])
-    required_args = argspec.args[:len(argspec.args) - num_defaults]
-
-    if getattr(fn, "__self__", None):
-        required_args.pop(0)
-
+    required_args = [
+        p.name for p in inspect.signature(fn).parameters.values()
+        if p.default == inspect.Parameter.empty
+        and p.kind == inspect.Parameter.POSITIONAL_OR_KEYWORD]
     missing_required_args = required_args[len(args):]
+
     missing = [arg for arg in missing_required_args if arg not in kwargs]
     if missing:
         raise MissingArgs(missing)
@@ -157,14 +151,9 @@ def print_list(objs, fields, formatters=None, sortby_index=0,
         table_header = make_table_header(table_label, table_width)
         table_header += "\n"
 
-    if six.PY3:
-        if table_header:
-            out.write(encodeutils.safe_encode(table_header).decode())
-        out.write(encodeutils.safe_encode(table_body).decode())
-    else:
-        if table_header:
-            out.write(encodeutils.safe_encode(table_header))
-        out.write(encodeutils.safe_encode(table_body))
+    if table_header:
+        out.write(encodeutils.safe_encode(table_header).decode())
+    out.write(encodeutils.safe_encode(table_body).decode())
 
 
 def print_dict(obj, fields=None, formatters=None, mixed_case_fields=False,
@@ -195,8 +184,8 @@ def print_dict(obj, fields=None, formatters=None, mixed_case_fields=False,
             fields = sorted(obj.keys())
         else:
             fields = [name for name in dir(obj)
-                      if (not name.startswith("_") and
-                          not callable(getattr(obj, name)))]
+                      if (not name.startswith("_")
+                          and not callable(getattr(obj, name)))]
 
     pt = prettytable.PrettyTable([property_label, value_label], caching=False)
     pt.align = "l"
@@ -219,12 +208,11 @@ def print_dict(obj, fields=None, formatters=None, mixed_case_fields=False,
         if isinstance(data, (dict, list)):
             data = json.dumps(data)
         if wrap > 0:
-            data = textwrap.fill(six.text_type(data), wrap)
+            data = textwrap.fill(str(data), wrap)
         # if value has a newline, add in multiple rows
         # e.g. fault with stacktrace
-        if (data and
-                isinstance(data, six.string_types) and
-                (r"\n" in data or "\r" in data)):
+        if (data and isinstance(data, str)
+                and (r"\n" in data or "\r" in data)):
             # "\r" would break the table, so remove it.
             if "\r" in data:
                 data = data.replace("\r", "")
@@ -248,14 +236,9 @@ def print_dict(obj, fields=None, formatters=None, mixed_case_fields=False,
         table_header = make_table_header(table_label, table_width)
         table_header += "\n"
 
-    if six.PY3:
-        if table_header:
-            out.write(encodeutils.safe_encode(table_header).decode())
-        out.write(encodeutils.safe_encode(table_body).decode())
-    else:
-        if table_header:
-            out.write(encodeutils.safe_encode(table_header))
-        out.write(encodeutils.safe_encode(table_body))
+    if table_header:
+        out.write(encodeutils.safe_encode(table_header).decode())
+    out.write(encodeutils.safe_encode(table_body).decode())
 
 
 def make_table_header(table_label, table_width,
@@ -508,6 +491,16 @@ def _compose_action_description(action_fn):
     return description
 
 
+def _print_version():
+    from rally.common import version
+
+    print("Rally version: %s" % version.version_string())
+    packages = version.plugins_versions()
+    if packages:
+        print("\nInstalled Plugins:")
+        print("\n".join("\t%s: %s" % p for p in sorted(packages.items())))
+
+
 def _add_command_parsers(categories, subparsers):
 
     # INFO(oanufriev) This monkey patching makes our custom parser class to be
@@ -515,8 +508,6 @@ def _add_command_parsers(categories, subparsers):
     # 'subparsers' parameter of this function (categories and actions).
     subparsers._parser_class = CategoryParser
 
-    parser = subparsers.add_parser("version")
-
     parser = subparsers.add_parser("bash-completion")
     parser.add_argument("query_category", nargs="?")
 
@@ -568,6 +559,10 @@ def validate_deprecated_args(argv, fn):
 
 
 def run(argv, categories):
+    if len(argv) > 1 and argv[1] in ["version", "--version"]:
+        _print_version()
+        return 0
+
     parser = lambda subparsers: _add_command_parsers(categories, subparsers)
     category_opt = cfg.SubCommandOpt("category",
                                      title="Command categories",
@@ -611,10 +606,6 @@ def run(argv, categories):
         print(e)
         return(2)
 
-    if CONF.category.name == "version":
-        print(CONF.version)
-        return(0)
-
     if CONF.category.name == "bash-completion":
         print(_generate_bash_completion_script())
         return(0)
@@ -629,7 +620,7 @@ def run(argv, categories):
         v = getattr(CONF.category, "action_kwarg_" + k)
         if v is None:
             continue
-        if isinstance(v, six.string_types):
+        if isinstance(v, str):
             v = encodeutils.safe_decode(v)
         fn_kwargs[k] = v
 
@@ -668,7 +659,8 @@ def run(argv, categories):
 
     except (IOError, TypeError, ValueError,
             exceptions.RallyException, jsonschema.ValidationError) as e:
-        if logging.is_debug():
+        known_errors = (exceptions.InvalidTaskConfig, )
+        if logging.is_debug() and not isinstance(e, known_errors):
             LOG.exception("Unexpected exception in CLI")
         else:
             print(e)
@@ -721,7 +713,7 @@ _rally()
     local cur="${COMP_WORDS[COMP_CWORD]}"
     local prev="${COMP_WORDS[COMP_CWORD-1]}"
 
-    if [[ $cur =~ ^(\.|\~|\/) ]] || [[ $prev =~ ^--out(|put-file)$ ]] ; then
+    if [[ $cur =~ ^(\\.|\\~|\\/) ]] || [[ $prev =~ ^--out(|put-file)$ ]] ; then
         _rally_filedir
     elif [[ $prev =~ ^--(task|filename)$ ]] ; then
         _rally_filedir "\\.json|\\.yaml|\\.yml"
