@@ -15,123 +15,35 @@
 
 """Rally command: task"""
 
-from __future__ import print_function
-import collections
-import datetime as dt
 import itertools
 import json
 import os
 import sys
 import webbrowser
 
-import jsonschema
-import six
-
 from rally.cli import cliutils
 from rally.cli import envutils
-from rally.common import fileutils
+from rally.cli import task_results_loader
+from rally.cli import yamlutils as yaml
 from rally.common import logging
 from rally.common import utils as rutils
 from rally.common import version
-from rally.common import yamlutils as yaml
 from rally import consts
 from rally import exceptions
 from rally import plugins
 from rally.task import atomic
 from rally.task.processing import charts
-from rally.task.processing import plot
-from rally.task import utils as tutils
 from rally.utils import strutils
 
 
 LOG = logging.getLogger(__name__)
 
-OLD_TASK_RESULT_SCHEMA = {
-    "type": "object",
-    "$schema": consts.JSON_SCHEMA,
-    "properties": {
-        "key": {
-            "type": "object",
-            "properties": {
-                "kw": {
-                    "type": "object"
-                },
-                "name": {
-                    "type": "string"
-                },
-                "pos": {
-                    "type": "integer"
-                },
-            },
-            "required": ["kw", "name", "pos"]
-        },
-        "sla": {
-            "type": "array",
-            "items": {
-                "type": "object",
-                "properties": {
-                    "criterion": {
-                        "type": "string"
-                    },
-                    "detail": {
-                        "type": "string"
-                    },
-                    "success": {
-                        "type": "boolean"
-                    }
-                }
-            }
-        },
-        "hooks": {"type": "array"},
-        "result": {
-            "type": "array",
-            "items": {
-                "type": "object",
-                "properties": {
-                    "atomic_actions": {
-                        "type": "object"
-                    },
-                    "duration": {
-                        "type": "number"
-                    },
-                    "error": {
-                        "type": "array"
-                    },
-                    "idle_duration": {
-                        "type": "number"
-                    },
-                    "output": {"type": "object"}
-                },
-                "required": ["atomic_actions", "duration", "error",
-                             "idle_duration"]
-            },
-            "minItems": 0
-        },
-        "load_duration": {
-            "type": "number",
-        },
-        "full_duration": {
-            "type": "number",
-        },
-        "created_at": {
-            "type": "string"
-        }
-    },
-    "required": ["key", "sla", "result", "load_duration", "full_duration"],
-    "additionalProperties": False
-}
-
 
 class FailedToLoadTask(exceptions.RallyException):
     error_code = 117
     msg_fmt = "Invalid %(source)s passed:\n\n\t %(msg)s"
 
 
-class FailedToLoadResults(exceptions.RallyException):
-    error_code = 225
-    msg_fmt = "ERROR: Invalid task result format in %(source)s\n\n\t%(msg)s"
-
-
 class TaskCommands(object):
     """Set of commands that allow you to manage tasks and results.
 
@@ -180,7 +92,7 @@ class TaskCommands(object):
         if raw_args:
             try:
                 data = yaml.safe_load(raw_args)
-                if isinstance(data, (six.text_type, six.string_types)):
+                if isinstance(data, str):
                     raise yaml.ParserError("String '%s' doesn't look like a "
                                            "dictionary." % raw_args)
                 task_args.update(data)
@@ -533,7 +445,7 @@ class TaskCommands(object):
         print("* To plot HTML graphics with this data, run:")
         print("\trally task report %s --out output.html\n" % task["uuid"])
         print("* To generate a JUnit report, run:")
-        print("\trally task export %s --type junit --to output.xml\n" %
+        print("\trally task export %s --type junit-xml --to output.xml\n" %
               task["uuid"])
         print("* To get raw JSON output of task results, run:")
         print("\trally task report %s --json --out output.json\n" %
@@ -547,70 +459,16 @@ class TaskCommands(object):
     @envutils.with_default_task_id
     @cliutils.suppress_warnings
     def results(self, api, task_id=None):
-        """Display raw task results.
-
-        This will produce a lot of output data about every iteration.
-        """
-
-        task = api.task.get(task_id=task_id, detailed=True)
-        finished_statuses = (consts.TaskStatus.FINISHED,
-                             consts.TaskStatus.ABORTED)
-        if task["status"] not in finished_statuses:
-            print("Task status is %s. Results available when it is one of %s."
-                  % (task["status"], ", ".join(finished_statuses)))
+        """DEPRECATED since Rally 3.0.0."""
+        LOG.warning("CLI method `rally task results` is deprecated since "
+                    "Rally 3.0.0 and will be removed soon. "
+                    "Use `rally task report --json` instead.")
+        try:
+            self.export(api, tasks=[task_id], output_type="old-json-results")
+        except exceptions.RallyException as e:
+            print(e.format_message())
             return 1
 
-        # TODO(chenhb): Ensure `rally task results` puts out old format.
-        for workload in itertools.chain(
-                *[s["workloads"] for s in task["subtasks"]]):
-            for itr in workload["data"]:
-                itr["atomic_actions"] = collections.OrderedDict(
-                    tutils.WrapperForAtomicActions(
-                        itr["atomic_actions"]).items()
-                )
-
-        results = []
-        for w in itertools.chain(*[s["workloads"] for s in task["subtasks"]]):
-            w["runner"]["type"] = w["runner_type"]
-
-            def port_hook_cfg(h):
-                h["config"] = {
-                    "name": h["config"]["action"][0],
-                    "args": h["config"]["action"][1],
-                    "description": h["config"].get("description", ""),
-                    "trigger": {"name": h["config"]["trigger"][0],
-                                "args": h["config"]["trigger"][1]}
-                }
-                return h
-
-            hooks = [port_hook_cfg(h) for h in w["hooks"]]
-
-            created_at = dt.datetime.strptime(w["created_at"],
-                                              "%Y-%m-%dT%H:%M:%S")
-            created_at = created_at.strftime("%Y-%d-%mT%H:%M:%S")
-
-            results.append({
-                "key": {
-                    "name": w["name"],
-                    "description": w["description"],
-                    "pos": w["position"],
-                    "kw": {
-                        "args": w["args"],
-                        "runner": w["runner"],
-                        "context": w["contexts"],
-                        "sla": w["sla"],
-                        "hooks": [h["config"] for h in w["hooks"]],
-                    }
-                },
-                "result": w["data"],
-                "sla": w["sla_results"].get("sla", []),
-                "hooks": hooks,
-                "load_duration": w["load_duration"],
-                "full_duration": w["full_duration"],
-                "created_at": created_at})
-
-        print(json.dumps(results, sort_keys=False, indent=4))
-
     @cliutils.args("--deployment", dest="deployment", type=str,
                    metavar="<uuid>", required=False,
                    help="UUID or name of a deployment.")
@@ -683,137 +541,6 @@ class TaskCommands(object):
                 print("There are no tasks. To run a new task, use:\n"
                       "\trally task start")
 
-    def _load_task_results_file(self, api, task_id):
-        """Load the json file which is created by `rally task results`"""
-
-        with open(os.path.expanduser(task_id)) as inp_js:
-            tasks_results = json.loads(inp_js.read())
-
-        if isinstance(tasks_results, list):
-            # it is an old format:
-
-            task = {"version": 2,
-                    "title": "Task loaded from a file.",
-                    "description": "Auto-ported from task format V1.",
-                    "uuid": "n/a",
-                    "env_name": "n/a",
-                    "env_uuid": "n/a",
-                    "tags": [],
-                    "status": consts.TaskStatus.FINISHED,
-                    "subtasks": []}
-
-            start_time = None
-
-            for result in tasks_results:
-                try:
-                    jsonschema.validate(
-                        result, OLD_TASK_RESULT_SCHEMA)
-                except jsonschema.ValidationError as e:
-                    raise FailedToLoadResults(source=task_id,
-                                              msg=six.text_type(e))
-
-                iter_count = 0
-                failed_iter_count = 0
-                min_duration = None
-                max_duration = None
-
-                for itr in result["result"]:
-                    if start_time is None or itr["timestamp"] < start_time:
-                        start_time = itr["timestamp"]
-                    # NOTE(chenhb): back compatible for atomic_actions
-                    itr["atomic_actions"] = list(
-                        tutils.WrapperForAtomicActions(itr["atomic_actions"],
-                                                       itr["timestamp"]))
-
-                    iter_count += 1
-                    if itr.get("error"):
-                        failed_iter_count += 1
-
-                    duration = itr.get("duration", 0)
-
-                    if max_duration is None or duration > max_duration:
-                        max_duration = duration
-
-                    if min_duration is None or min_duration > duration:
-                        min_duration = duration
-
-                durations_stat = charts.MainStatsTable(
-                    {"total_iteration_count": iter_count})
-
-                for itr in result["result"]:
-                    durations_stat.add_iteration(itr)
-
-                created_at = dt.datetime.strptime(result["created_at"],
-                                                  "%Y-%d-%mT%H:%M:%S")
-                updated_at = created_at + dt.timedelta(
-                    seconds=result["full_duration"])
-                created_at = created_at.strftime(consts.TimeFormat.ISO8601)
-                updated_at = updated_at.strftime(consts.TimeFormat.ISO8601)
-                pass_sla = all(s.get("success") for s in result["sla"])
-                runner_type = result["key"]["kw"]["runner"].pop("type")
-                for h in result["hooks"]:
-                    trigger = h["config"]["trigger"]
-                    h["config"] = {
-                        "description": h["config"].get("description"),
-                        "action": (h["config"]["name"], h["config"]["args"]),
-                        "trigger": (trigger["name"], trigger["args"])}
-                workload = {"uuid": "n/a",
-                            "name": result["key"]["name"],
-                            "position": result["key"]["pos"],
-                            "description": result["key"].get("description",
-                                                             ""),
-                            "full_duration": result["full_duration"],
-                            "load_duration": result["load_duration"],
-                            "total_iteration_count": iter_count,
-                            "failed_iteration_count": failed_iter_count,
-                            "min_duration": min_duration,
-                            "max_duration": max_duration,
-                            "start_time": start_time,
-                            "created_at": created_at,
-                            "updated_at": updated_at,
-                            "args": result["key"]["kw"]["args"],
-                            "runner_type": runner_type,
-                            "runner": result["key"]["kw"]["runner"],
-                            "hooks": result["hooks"],
-                            "sla": result["key"]["kw"]["sla"],
-                            "sla_results": {"sla": result["sla"]},
-                            "pass_sla": pass_sla,
-                            "contexts": result["key"]["kw"]["context"],
-                            "contexts_results": [],
-                            "data": sorted(result["result"],
-                                           key=lambda x: x["timestamp"]),
-                            "statistics": {
-                                "durations": durations_stat.to_dict()},
-                            }
-                task["subtasks"].append(
-                    {"title": "A SubTask",
-                     "description": "",
-                     "workloads": [workload]})
-            return [task]
-        elif isinstance(tasks_results, dict) and "tasks" in tasks_results:
-            for task_result in tasks_results["tasks"]:
-                try:
-                    jsonschema.validate(task_result,
-                                        api.task.TASK_SCHEMA)
-                except jsonschema.ValidationError as e:
-                    msg = six.text_type(e)
-                    raise exceptions.RallyException(
-                        "ERROR: Invalid task result format\n\n\t%s" % msg)
-                task_result.setdefault("env_name", "n/a")
-                task_result.setdefault("env_uuid", "n/a")
-                for subtask in task_result["subtasks"]:
-                    for workload in subtask["workloads"]:
-                        workload.setdefault("contexts_results", [])
-                        workload["runner_type"], workload["runner"] = list(
-                            workload["runner"].items())[0]
-                        workload["name"], workload["args"] = list(
-                            workload.pop("scenario").items())[0]
-
-            return tasks_results["tasks"]
-        else:
-            raise FailedToLoadResults(
-                source=task_id, msg="Wrong format")
-
     @cliutils.args("--out", metavar="<path>",
                    type=str, dest="out", required=False,
                    help="Path to output file.")
@@ -821,43 +548,22 @@ class TaskCommands(object):
                    help="Open the output in a browser.")
     @cliutils.args("--tasks", dest="tasks", nargs="+",
                    help="UUIDs of tasks, or JSON files with task results")
+    @cliutils.args("--html-static", dest="out_format",
+                   action="store_const", const="trends-html-static")
     @cliutils.suppress_warnings
     def trends(self, api, *args, **kwargs):
         """Generate workloads trends HTML report."""
-
         tasks = kwargs.get("tasks", []) or list(args)
-
         if not tasks:
             print("ERROR: At least one task must be specified",
                   file=sys.stderr)
             return 1
 
-        results = []
-        for task_id in tasks:
-            if os.path.exists(os.path.expanduser(task_id)):
-                results.extend(self._load_task_results_file(api, task_id))
-            elif strutils.is_uuid_like(task_id):
-                results.append(api.task.get(task_id=task_id, detailed=True))
-            else:
-                print("ERROR: Invalid UUID or file name passed: %s" % task_id,
-                      file=sys.stderr)
-                return 1
+        self.export(api, tasks=tasks,
+                    output_type=kwargs.get("out_format", "trends-html"),
+                    output_dest=kwargs.get("out"),
+                    open_it=kwargs.get("open_it", False))
 
-        result = plot.trends(results)
-
-        out = kwargs.get("out")
-        if out:
-            output_file = os.path.expanduser(out)
-
-            with open(output_file, "w+") as f:
-                f.write(result)
-            if kwargs.get("open_it"):
-                webbrowser.open_new_tab("file://" + os.path.realpath(out))
-        else:
-            print(result)
-
-    @cliutils.deprecated_args("--tasks", dest="tasks", nargs="+",
-                              release="0.10.0", alternative="--uuid")
     @cliutils.args("--out", metavar="<path>",
                    type=str, dest="out", required=False,
                    help="Report destination. Can be a path to a file (in case"
@@ -871,22 +577,21 @@ class TaskCommands(object):
                    action="store_const", const="html-static")
     @cliutils.args("--json", dest="out_format",
                    action="store_const", const="json")
-    @cliutils.deprecated_args("--junit", dest="out_format",
-                              action="store_const", const="junit-xml",
-                              release="0.10.0",
-                              alternative=("rally task export "
-                                           "--type junit-xml"))
     @cliutils.args("--uuid", dest="tasks", nargs="+", type=str,
                    help="UUIDs of tasks or json reports of tasks")
+    @cliutils.args("--deployment", dest="deployment", type=str,
+                   help="Report all tasks with defined deployment",
+                   required=False)
     @envutils.default_from_global("tasks", envutils.ENV_TASK, "uuid")
     @cliutils.suppress_warnings
     def report(self, api, tasks=None, out=None,
-               open_it=False, out_format="html"):
+               open_it=False, out_format="html", deployment=None):
         """Generate a report for the specified task(s)."""
         self.export(api, tasks=tasks,
                     output_type=out_format,
                     output_dest=out,
-                    open_it=open_it)
+                    open_it=open_it,
+                    deployment=deployment)
 
     @cliutils.args("--force", action="store_true", help="force delete")
     @cliutils.args("--uuid", type=str, dest="task_id", nargs="*",
@@ -911,17 +616,6 @@ class TaskCommands(object):
         else:
             _delete_single_task(task_id, force)
 
-    @cliutils.args("--uuid", type=str, dest="task_id", help="UUID of task.")
-    @cliutils.args("--json", dest="tojson",
-                   action="store_true",
-                   help="Output in JSON format.")
-    @envutils.with_default_task_id
-    @cliutils.alias("sla_check")
-    def sla_check_deprecated(self, api, task_id=None, tojson=False):
-        """DEPRECATED since Rally 0.8.0, use `rally task sla-check` instead."""
-
-        return self.sla_check(api, task_id=task_id, tojson=tojson)
-
     @cliutils.args("--uuid", type=str, dest="task_id", help="UUID of task.")
     @cliutils.args("--json", dest="tojson",
                    action="store_true",
@@ -950,18 +644,18 @@ class TaskCommands(object):
         else:
             cliutils.print_list(data, ("benchmark", "pos", "criterion",
                                        "status", "detail"))
+        if not data:
+            return 2
         return failed_criteria
 
     @cliutils.args("--uuid", type=str, dest="task_id",
                    help="UUID of the task")
-    @cliutils.deprecated_args("--task", dest="task_id", type=str,
-                              release="0.2.0", alternative="--uuid")
     def use(self, api, task_id):
         """Set active task."""
 
         print("Using task: %s" % task_id)
         api.task.get(task_id=task_id)
-        fileutils.update_globals_file("RALLY_TASK", task_id)
+        envutils.update_globals_file("RALLY_TASK", task_id)
 
     @cliutils.args("--uuid", dest="tasks", nargs="+", type=str,
                    help="UUIDs of tasks or json reports of tasks")
@@ -979,18 +673,26 @@ class TaskCommands(object):
                         "types) to save the report to or a connection string."
                         " It depends on the report type."
                    )
+    @cliutils.args("--deployment", dest="deployment", type=str,
+                   help="Report all tasks with defined deployment",
+                   required=False)
     @envutils.default_from_global("tasks", envutils.ENV_TASK, "uuid")
     @plugins.ensure_plugins_are_loaded
     def export(self, api, tasks=None, output_type=None, output_dest=None,
-               open_it=False):
+               open_it=False, deployment=None):
         """Export task results to the custom task's exporting system."""
-        tasks = isinstance(tasks, list) and tasks or [tasks]
+
+        if deployment is not None:
+            tasks = api.task.list(deployment=deployment, uuids_only=True)
+            tasks = [task["uuid"] for task in tasks]
+        else:
+            tasks = isinstance(tasks, list) and tasks or [tasks]
 
         exported_tasks = []
         for task_file_or_uuid in tasks:
             if os.path.exists(os.path.expanduser(task_file_or_uuid)):
                 exported_tasks.extend(
-                    self._load_task_results_file(api, task_file_or_uuid)
+                    task_results_loader.load(task_file_or_uuid)
                 )
             else:
                 exported_tasks.append(task_file_or_uuid)
@@ -1047,7 +749,7 @@ class TaskCommands(object):
         """Import json results of a test into rally database"""
 
         if os.path.exists(os.path.expanduser(task_file)):
-            tasks_results = self._load_task_results_file(api, task_file)
+            tasks_results = task_results_loader.load(task_file)
             for task_results in tasks_results:
                 task = api.task.import_results(deployment=deployment,
                                                task_results=task_results,
