@@ -13,12 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import unittest
+import testtools
 
 from tests.functional import utils
 
 
-class PluginTestCase(unittest.TestCase):
+class PluginTestCase(testtools.TestCase):
 
     def test_show_one(self):
         rally = utils.Rally()
@@ -30,29 +30,32 @@ class PluginTestCase(unittest.TestCase):
 
     def test_show_multiple(self):
         rally = utils.Rally()
-        result = rally("plugin show Dummy")
-        self.assertIn("Multiple plugins found:", result)
-        self.assertIn("Dummy.dummy", result)
-        self.assertIn("Dummy.dummy_exception", result)
-        self.assertIn("Dummy.dummy_random_fail_in_atomic", result)
+        result = self.assertRaises(utils.RallyCliError,
+                                   rally, "plugin show Dummy")
+        self.assertIn("Multiple plugins found:", result.output)
+        self.assertIn("Dummy.dummy", result.output)
+        self.assertIn("Dummy.dummy_exception", result.output)
+        self.assertIn("Dummy.dummy_random_fail_in_atomic", result.output)
 
     def test_show_not_found(self):
         rally = utils.Rally()
         name = "Dummy666666"
-        result = rally("plugin show %s" % name)
-        self.assertIn("Plugin %s not found" % name, result)
+        result = self.assertRaises(utils.RallyCliError,
+                                   rally, "plugin show %s" % name)
+        self.assertIn("Plugin %s not found" % name, result.output)
 
     def test_show_not_found_in_specific_platform(self):
         rally = utils.Rally()
         name = "Dummy"
         platform = "non_existing"
-        result = rally(
-            "plugin show --name %(name)s --platform %(platform)s"
-            % {"name": name, "platform": platform})
+        result = self.assertRaises(
+            utils.RallyCliError,
+            rally, "plugin show --name %(name)s --platform %(platform)s"
+                   % {"name": name, "platform": platform})
         self.assertIn(
             "Plugin %(name)s@%(platform)s not found"
             % {"name": name, "platform": platform},
-            result)
+            result.output)
 
     def test_list(self):
         rally = utils.Rally()
