@@ -18,10 +18,10 @@ import os
 import re
 import threading
 import time
-import unittest
+from unittest import mock
 
 import jsonschema
-import mock
+import testtools
 
 from rally import api
 from tests.functional import utils
@@ -30,7 +30,7 @@ from tests.functional import utils
 FAKE_TASK_UUID = "87ab639d-4968-4638-b9a1-07774c32484a"
 
 
-class TaskTestCase(unittest.TestCase):
+class TaskTestCase(testtools.TestCase):
 
     def _get_sample_task_config(self):
         return {
@@ -156,11 +156,9 @@ class TaskTestCase(unittest.TestCase):
             ]
         }
         config = utils.TaskConfig(cfg)
-        try:
-            # it should be failed due to Dummy.dummy_exception
-            rally("task start --task %s" % config.filename)
-        except utils.RallyCliError:
-            pass
+        # it should be failed due to Dummy.dummy_exception
+        self.assertRaises(utils.RallyCliError,
+                          rally, "task start --task %s" % config.filename)
         output = rally("task detailed --filter-by sla-failures")
         self.assertIn("Dummy.dummy_exception", output)
         self.assertNotIn("Dummy.dummy_random_action", output)
@@ -211,10 +209,11 @@ class TaskTestCase(unittest.TestCase):
     def test_start_with_empty_config(self):
         rally = utils.Rally()
         config = utils.TaskConfig(None)
-        with self.assertRaises(utils.RallyCliError) as err:
-            rally("task start --task %s" % config.filename)
+        err = self.assertRaises(
+            utils.RallyCliError,
+            rally, "task start --task %s" % config.filename)
         self.assertIn("Task config is invalid: `It is empty`",
-                      err.exception.output)
+                      err.output)
 
     def test_results(self):
         rally = utils.Rally()
@@ -237,14 +236,14 @@ class TaskTestCase(unittest.TestCase):
         with open(json_report, "w+") as f:
             f.write(rally("task results", no_logs=True))
         import_print = rally("task import --file %s" % json_report)
-        task_uuid = re.search("UUID:\s([a-z0-9\-]+)", import_print).group(1)
+        task_uuid = re.search(r"UUID:\s([a-z0-9\-]+)", import_print).group(1)
         self.assertIn("Dummy.dummy_random_fail_in_atomic",
                       rally("task results --uuid %s" % task_uuid))
 
         # new json report
         rally("task report --json --out %s" % json_report, no_logs=True)
         import_print = rally("task import --file %s" % json_report)
-        task_uuid = re.search("UUID:\s([a-z0-9\-]+)", import_print).group(1)
+        task_uuid = re.search(r"UUID:\s([a-z0-9\-]+)", import_print).group(1)
         self.assertIn("Dummy.dummy_random_fail_in_atomic",
                       rally("task report --uuid %s --json" % task_uuid))
 
@@ -265,10 +264,11 @@ class TaskTestCase(unittest.TestCase):
 
     def test_report_with_wrong_task_id(self):
         rally = utils.Rally()
-        self.assertRaises(utils.RallyCliError,
-                          rally, "task report --tasks %s" % FAKE_TASK_UUID)
-        self.assertRaises(utils.RallyCliError,
-                          rally, "task report --uuid %s" % FAKE_TASK_UUID)
+        e = self.assertRaises(utils.RallyCliError,
+                              rally, "task report --uuid %s" % FAKE_TASK_UUID)
+        self.assertIn(
+            "Record for uuid: %s not found in table task" % FAKE_TASK_UUID,
+            str(e))
 
     def test_sla_check_with_wrong_task_id(self):
         rally = utils.Rally()
@@ -365,7 +365,8 @@ class TaskTestCase(unittest.TestCase):
         rally("task start --task %s" % config.filename)
         task_result_file = rally.gen_report_path(suffix="results")
         self.addCleanup(os.remove, task_result_file)
-        rally("task results", report_path=task_result_file, raw=True)
+        rally("task results", report_path=task_result_file, raw=True,
+              getjson=True)
 
         html_report = rally.gen_report_path(extension="html")
         rally("task report --html-static %s --out %s"
@@ -604,7 +605,7 @@ class TaskTestCase(unittest.TestCase):
         plugin_paths = ("tests/functional/extra/fake_dir1/,"
                         "tests/functional/extra/fake_dir2/")
         task_file = "tests/functional/extra/test_fake_scenario.json"
-        output = rally(("--plugin-paths %(plugin_paths)s "
+        output = rally(("--debug --plugin-paths %(plugin_paths)s "
                         "task validate --task %(task_file)s") %
                        {"task_file": task_file,
                         "plugin_paths": plugin_paths})
@@ -999,7 +1000,7 @@ class TaskTestCase(unittest.TestCase):
         result = re.search(
             r"(?P<uuid>[0-9a-f\-]{36}): started", output)
         uuid = result.group("uuid")
-        rally("task use --task %s" % uuid)
+        rally("task use --uuid %s" % uuid)
         current_task = utils.get_global("RALLY_TASK", rally.env)
         self.assertEqual(uuid, current_task)
 
@@ -1050,7 +1051,7 @@ class TaskTestCase(unittest.TestCase):
         self.assertTrue(os.path.exists(html_report))
 
 
-class SLATestCase(unittest.TestCase):
+class SLATestCase(testtools.TestCase):
 
     def _get_sample_task_config(self, max_seconds_per_iteration=4,
                                 failure_rate_max=0):
@@ -1077,9 +1078,10 @@ class SLATestCase(unittest.TestCase):
         rally = utils.Rally()
         cfg = self._get_sample_task_config(max_seconds_per_iteration=0.001)
         config = utils.TaskConfig(cfg)
-        with self.assertRaises(utils.RallyCliError) as err:
-            rally("task start --task %s" % config.filename)
-        output = err.exception.output
+        err = self.assertRaises(
+            utils.RallyCliError,
+            rally, "task start --task %s" % config.filename)
+        output = err.output
         self.assertIn("At least one workload did not pass SLA criteria.",
                       output)
         self.assertRaises(utils.RallyCliError, rally, "task sla-check")
@@ -1103,7 +1105,7 @@ class SLATestCase(unittest.TestCase):
         self.assertEqual(expected, data)
 
 
-class SLAExtraFlagsTestCase(unittest.TestCase):
+class SLAExtraFlagsTestCase(testtools.TestCase):
 
     def test_abort_on_sla_fail(self):
         rally = utils.Rally()
@@ -1135,13 +1137,9 @@ class SLAExtraFlagsTestCase(unittest.TestCase):
              "detail": mock.ANY,
              "pos": 0, "status": "FAIL"}
         ]
-        try:
-            rally("task sla-check --json", getjson=True)
-        except utils.RallyCliError as expected_error:
-            self.assertEqual(expected, json.loads(expected_error.output))
-        else:
-            self.fail("`rally task sla-check` command should return non-zero "
-                      "exit code")
+        e = self.assertRaises(utils.RallyCliError,
+                              rally, "task sla-check --json", getjson=True)
+        self.assertEqual(expected, json.loads(e.output))
 
     def _test_broken_context(self, runner):
         rally = utils.Rally()
@@ -1170,13 +1168,9 @@ class SLAExtraFlagsTestCase(unittest.TestCase):
              "detail": mock.ANY,
              "pos": 0, "status": "FAIL"}
         ]
-        try:
-            rally("task sla-check --json", getjson=True)
-        except utils.RallyCliError as expected_error:
-            self.assertEqual(expected, json.loads(expected_error.output))
-        else:
-            self.fail("`rally task sla-check` command should return non-zero "
-                      "exit code")
+        e = self.assertRaises(utils.RallyCliError,
+                              rally, "task sla-check --json", getjson=True)
+        self.assertEqual(expected, json.loads(e.output))
 
     def test_broken_context_with_constant_runner(self):
         self._test_broken_context({"type": "constant",
@@ -1190,7 +1184,7 @@ class SLAExtraFlagsTestCase(unittest.TestCase):
                                    "timeout": 6})
 
 
-class SLAPerfDegrTestCase(unittest.TestCase):
+class SLAPerfDegrTestCase(testtools.TestCase):
 
     def _get_sample_task_config(self, max_degradation=500):
         return {
@@ -1219,9 +1213,10 @@ class SLAPerfDegrTestCase(unittest.TestCase):
         rally = utils.Rally()
         cfg = self._get_sample_task_config(max_degradation=1)
         config = utils.TaskConfig(cfg)
-        with self.assertRaises(utils.RallyCliError) as err:
-            rally("task start --task %s" % config.filename)
-        output = err.exception.output
+        err = self.assertRaises(
+            utils.RallyCliError,
+            rally, "task start --task %s" % config.filename)
+        output = err.output
         self.assertIn("At least one workload did not pass SLA criteria.",
                       output)
         self.assertRaises(utils.RallyCliError, rally, "task sla-check")
@@ -1241,7 +1236,7 @@ class SLAPerfDegrTestCase(unittest.TestCase):
         self.assertEqual(expected, data)
 
 
-class HookTestCase(unittest.TestCase):
+class HookTestCase(testtools.TestCase):
 
     def setUp(self):
         super(HookTestCase, self).setUp()
@@ -1420,8 +1415,7 @@ class HookTestCase(unittest.TestCase):
         self.assertEqual(
             expected,
             sorted(hook_results,
-                   key=lambda i: list(
-                       i["config"]["trigger"].values())[0]["unit"]))
+                   key=lambda i: i["config"]["trigger"]["args"]["unit"]))
         self._assert_results_time(hook_results)
 
     def test_import_hook_result(self):
@@ -1460,7 +1454,7 @@ class HookTestCase(unittest.TestCase):
         with open(json_report, "w+") as f:
             f.write(rally("task results", no_logs=True))
         import_print = rally("task import --file %s" % json_report)
-        task_uuid = re.search("UUID:\s([a-z0-9\-]+)", import_print).group(1)
+        task_uuid = re.search(r"UUID:\s([a-z0-9\-]+)", import_print).group(1)
         results = rally("task results --uuid %s" % task_uuid)
         self.assertIn("Dummy.dummy", results)
         self.assertIn("event_hook", results)
