@@ -13,9 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import io
+from unittest import mock
+
 import ddt
-import mock
-import six
 import sqlalchemy.exc
 
 from rally.cli import cliutils
@@ -47,7 +48,7 @@ class CliUtilsTestCase(test.TestCase):
         super(CliUtilsTestCase, self).tearDown()
 
     def test_print_dict(self):
-        out = six.StringIO()
+        out = io.StringIO()
         dict = {"key": "value"}
         cliutils.print_dict(dict, out=out)
         self.assertEqual("+----------+-------+\n"
@@ -58,7 +59,7 @@ class CliUtilsTestCase(test.TestCase):
                          out.getvalue())
 
     def test_print_dict_wrap(self):
-        out = six.StringIO()
+        out = io.StringIO()
         dict = {"key1": "not wrapped",
                 "key2": "this will be wrapped"}
         cliutils.print_dict(dict, wrap=16, out=out)
@@ -72,7 +73,7 @@ class CliUtilsTestCase(test.TestCase):
                          out.getvalue())
 
     def test_print_dict_formatters_and_fields(self):
-        out = six.StringIO()
+        out = io.StringIO()
         dict = {"key1": "value",
                 "key2": "Value",
                 "key3": "vvv"}
@@ -90,7 +91,7 @@ class CliUtilsTestCase(test.TestCase):
                          out.getvalue())
 
     def test_print_dict_header(self):
-        out = six.StringIO()
+        out = io.StringIO()
         dict = {"key": "value"}
         cliutils.print_dict(dict, table_label="Some Table", print_header=False,
                             out=out)
@@ -122,7 +123,7 @@ class CliUtilsTestCase(test.TestCase):
             def foobar():
                 pass
 
-        out = six.StringIO()
+        out = io.StringIO()
         formatters = {"c": lambda x: "a + b = %s" % x.c}
         cliutils.print_dict(SomeStruct(1, 2), formatters=formatters, out=out)
         self.assertEqual("+----------+-----------+\n"
@@ -135,7 +136,7 @@ class CliUtilsTestCase(test.TestCase):
                          out.getvalue())
 
     def test_print_dict_with_spec_chars(self):
-        out = six.StringIO()
+        out = io.StringIO()
         dict = {"key": "line1\r\nline2"}
         cliutils.print_dict(dict, out=out)
         self.assertEqual("+----------+-------+\n"
@@ -245,10 +246,10 @@ class CliUtilsTestCase(test.TestCase):
     @mock.patch("rally.api.API",
                 side_effect=exceptions.RallyException("config_file"))
     def test_run_fails(self, mock_rally_api_api):
-        ret = cliutils.run(["rally", "version"], self.categories)
+        ret = cliutils.run(["rally", "task list"], self.categories)
         self.assertEqual(2, ret)
         mock_rally_api_api.assert_called_once_with(
-            config_args=["version"], skip_db_check=True)
+            config_args=["task list"], skip_db_check=True)
 
     @mock.patch("rally.api.API.check_db_revision")
     def test_run_version(self, mock_api_check_db_revision):
@@ -441,13 +442,13 @@ class CliUtilsTestCase(test.TestCase):
                       "+---+---+")})
     @ddt.unpack
     def test_print_list(self, args, kwargs, expected):
-        out = six.moves.StringIO()
+        out = io.StringIO()
         kwargs["out"] = out
         cliutils.print_list(*args, **kwargs)
         self.assertEqual(expected, out.getvalue().strip())
 
     def test_print_list_raises(self):
-        out = six.moves.StringIO()
+        out = io.StringIO()
         self.assertRaisesRegex(
             ValueError,
             "Field labels list.*has different number "
@@ -922,6 +923,28 @@ class ValidateArgsTest(test.TestCase):
         wrapped = cliutils.alias(cmd_name)
         self.assertEqual(cmd_name, wrapped(alias_fn).alias)
 
+    def test_deprecated_args(self):
+        def command():
+            pass
+
+        def deprecated_args(func, *args, **kwargs):
+            cliutils.deprecated_args(*args, **kwargs)(func)
+
+        e = self.assertRaises(ValueError, deprecated_args, command,
+                              "--argument-name", type="const")
+        self.assertIn("'release' is required keyword argument", str(e))
+        self.assertNotIn("args", command.__dict__)
+        self.assertNotIn("deprecated_args", command.__dict__)
+
+        @cliutils.deprecated_args("--argument-name", type="const", release=777)
+        def command():
+            pass
+
+        self.assertEqual(1, len(command.__dict__.get("args", [])))
+        arg_kwargs = command.__dict__["args"][0][1]
+        self.assertIn("[Deprecated since Rally 777]",
+                      arg_kwargs.get("help", ""))
+
 
 class CategoryParserTestCase(test.TestCase):
 
